==> yam-0.7.1.tar.gz: yam-0.7.1/README.md <==
## yam
Yet another monitoring tool using correlations of ambient noise

[![build status](https://github.com/trichter/yam/workflows/tests/badge.svg)](https://github.com/trichter/yam/actions)
[![codecov](https://codecov.io/gh/trichter/yam/branch/master/graph/badge.svg)](https://codecov.io/gh/trichter/yam)
[![pypi version](https://img.shields.io/pypi/v/yam.svg)](https://pypi.python.org/pypi/yam)
[![python version](https://img.shields.io/pypi/pyversions/yam.svg)](https://python.org)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3953646.svg)](https://doi.org/10.5281/zenodo.3953646)


#### Resources

* [Documentation](http://yam.readthedocs.io)
* Example: Inter-station cross-correlations -> [notebook](https://nbviewer.jupyter.org/github/trichter/notebooks/blob/master/yam_xcorr_ipoc/xcorr_ipoc.ipynb)
* Showcase / advanced tutorial: Monitoring seismic velocity -> [notebook](http://nbviewer.jupyter.org/github/trichter/notebooks/blob/master/yam_velocity_variations_patcx/processing_patcx.ipynb)
* Yam poster at EGU 2018, doi: [10.6084/m9.figshare.16976017](https://doi.org/10.6084/m9.figshare.16976017)
* Get help or discuss in the ObsPy forum, please use the [ObsPy Related Projects category](https://discourse.obspy.org/c/obspy-related-projects)


#### Citation

If you found this package useful, please consider citing it.

Eulenfeld T (2020),
yam: Yet another monitoring tool using correlations of ambient noise,
https://github.com/trichter/yam,
doi:[10.5281/zenodo.3953646](https://doi.org/10.5281/zenodo.3953646)

==> yam-0.7.2.tar.gz: yam-0.7.2/README.md <==
## yam
Yet another monitoring tool using correlations of ambient noise

[![build status](https://github.com/trichter/yam/workflows/tests/badge.svg)](https://github.com/trichter/yam/actions)
[![codecov](https://codecov.io/gh/trichter/yam/branch/master/graph/badge.svg)](https://codecov.io/gh/trichter/yam)
[![pypi version](https://img.shields.io/pypi/v/yam.svg)](https://pypi.python.org/pypi/yam)
[![python version](https://img.shields.io/pypi/pyversions/yam.svg)](https://python.org)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3953646.svg)](https://doi.org/10.5281/zenodo.3953646)

`yam` is a Python-based command line package for correlating seismic recordings of ambient vibrations and for the monitoring of relative seismic velocity changes.

#### Resources

* [Documentation](http://yam.readthedocs.io) including installation instructions
* Example: Inter-station cross-correlations -> [notebook](https://nbviewer.jupyter.org/github/trichter/notebooks/blob/master/yam_xcorr_ipoc/xcorr_ipoc.ipynb)
* Showcase / advanced tutorial: Monitoring seismic velocity -> [notebook](http://nbviewer.jupyter.org/github/trichter/notebooks/blob/master/yam_velocity_variations_patcx/processing_patcx.ipynb)
* Yam poster at EGU 2018, doi: [10.6084/m9.figshare.16976017](https://doi.org/10.6084/m9.figshare.16976017)
* Get help or discuss in the ObsPy forum, please use the [ObsPy Related Projects category](https://discourse.obspy.org/c/obspy-related-projects)
* You are welcome to contribute code by opening pull requests or report bugs in the issue tracker


#### Citation

If you found this package useful, please consider citing it.

Eulenfeld T (2020),
yam: Yet another monitoring tool using correlations of ambient noise,
https://github.com/trichter/yam,
doi:[10.5281/zenodo.3953646](https://doi.org/10.5281/zenodo.3953646)
